%global  checkout   eb397e7d80a7b275bc459d4285215421b0e09d8f
%global  date       20161222

Name:    molequeue
Summary: Desktop integration of high performance computing resources
Version: 0.8.0
Release: 6.%{date}git%(echo %{checkout} | cut -c-6)%{?dist}
License: BSD
URL:     https://github.com/OpenChemistry/molequeue
Source0: https://github.com/OpenChemistry/molequeue/archive/%{checkout}.zip#/%{name}-%{checkout}.zip

# Fix CMake config file compatibility with GCC7
Patch0: %{name}-fix_gcc7_compatibility.patch

## Main building
BuildRequires: qt5-qtbase-devel, qt5-rpm-macros
BuildRequires: qt5-qtwebkit-devel
%if 0%{?fedora}
BuildRequires: qjson-qt5-devel
%endif
BuildRequires: qt5-qttools-devel
BuildRequires: qt5-qtscript-devel
BuildRequires: qt5-qtsvg-devel
BuildRequires: qt5-qtxmlpatterns-devel
BuildRequires: desktop-file-utils
BuildRequires: gcc-c++, doxygen
BuildRequires: python2-devel
BuildRequires: cmake, ImageMagick

Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description
MoleQueue is an open-source, cross-platform, system-tray resident desktop
application for abstracting, managing, and coordinating the execution of tasks
both locally and on remote computational resources. Users can set up local and
remote queues that describe where the task will be executed. Each queue can
have programs, with templates to facilitate the execution of the program. Input
files can be staged, and output files collected using a standard interface.
Some highlights:

* Open source distributed under the liberal 3-clause BSD license
* Cross platform with nightly builds on Linux, Mac OS X and Windows
* Intuitive interface designed to be useful to whole community
* Support for local executation and remote schedulers (SGE, PBS, SLURM)
* System tray resident application managing queue of queues and job lifetime
* Simple, lightweight JSON-RPC 2.0 based communication over local sockets
* Qt 5 client library for simple integration in Qt applications

%package libs
Summary: Shared and private libraries of %{name}

%description libs
Shared and private libraries of %{name}.

%package  devel
Summary:  Development files of %{name}
Requires: qt5-qtbase-devel
Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package contains libraries and header files for developing
applications that use %{name}.

%package doc
Summary: HTML documentation of %{name}
BuildArch: noarch
%description doc
HTML documentation of %{name}.

%prep
%setup -q -n %{name}-%{checkout}
%if 0%{?fedora}
%patch0 -p0
%endif

convert molequeue/app/icons/molequeue.ico molequeue/app/icons/molequeue.png

%if 0%{?fedora}
rm -rf thirdparty/qt5json
%endif

%build
mkdir build && cd build
%cmake -Wno-dev \
 -DENABLE_RPATH:BOOL=OFF \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES \
 -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DENABLE_TESTING:BOOL=OFF \
 -DBUILD_DOCUMENTATION:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE:BOOL=TRUE \
 -DPYTHON_EXECUTABLE:FILEPATH=%{__python2} \
 -DCMAKE_BUILD_TYPE:STRING=Release ..

%make_build

pushd docs
doxygen
popd

%install
%make_install -C build

rm -rf %{buildroot}%{_datadir}/doc

cat >%{name}.desktop <<EOF
[Desktop Entry]
Name=MoleQueue
Comment=Manage HPC jobs from the system tray
Exec=%{name}
Terminal=false
Type=Application
Icon=%{name}
EOF
for i in molequeue/app/icons/%{name}-*.png; do
    size="$(identify $i|cut -d' ' -f3)"
    install -Dpm0644 $i %{buildroot}%{_datadir}/icons/hicolor/$size/apps/%{name}.png
done

desktop-file-install %{name}.desktop --dir %{buildroot}%{_datadir}/applications

%post
/sbin/ldconfig
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%files libs
%doc README.md
%license COPYING
%{_libdir}/*.so
%{_libdir}/%{name}/

%files devel
%{_libdir}/cmake/%{name}/
%{_includedir}/%{name}/

%files doc
%doc README.md build/docs/html
%license COPYING

%changelog
* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-6.20161222giteb397e
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0-5.20161222giteb397e
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 02 2017 Antonio Trande <sagitter@fedoraproject.org> - 0.8.0-4.20161222giteb397e
- Unbundle qjson-qt5 on fedora only

* Thu Jun 22 2017 Antonio Trande <sagitter@fedoraproject.org> - 0.8.0-3.20161222giteb397e
- Modified for epel builds

* Fri Mar 17 2017 Antonio Trande <sagitter@fedoraproject.org> - 0.8.0-2.20161222giteb397e
- Add a .desktop file

* Sat Mar 11 2017 Antonio Trande <sagitter@fedoraproject.org> - 0.8.0-1.20161222giteb397e
- First package
